@@ -175,7 +175,8 @@ class gdaAttack:
         self._claimCounter = 0
         self._guessCounter = 0
         # State for duplicate claim detection
-        self._dupCheck = DupCheck()
+        # Temp disable because buggy
+        #self._dupCheck = DupCheck()
         # State for computing attack results (see _initAtkRes())
         self._atrs = {}
         # State for various operational measures (see _initOp())
@@ -311,6 +312,8 @@ class gdaAttack:
             sys.exit(exitMsg)
 
     def isClaimed(self, spec):
+        # Temp disable because buggy
+        return False
         return self._dupCheck.is_claimed(spec, verbose=self._vb)
 
     def askClaim(self, spec, cache=True, claim=True):
@@ -338,8 +341,9 @@ class gdaAttack:
         Answers are cached <br/>
         Returns immediately"""
         if self._vb: print(f"Calling {__name__}.askClaim with spec '{spec}', count {self._claimCounter}")
-        if not self._dupCheck.is_claimed(spec, verbose=self._vb, raise_true=True):
-            self._dupCheck.claim(spec, verbose=self._vb)
+        # Temp disable because buggy
+        #if not self._dupCheck.is_claimed(spec, verbose=self._vb, raise_true=True):
+            #self._dupCheck.claim(spec, verbose=self._vb)
         self._claimCounter += 1
         sql = self._makeSqlFromSpec(spec)
         if self._vb: print(f"Sql is '{sql}'")
